summaryrefslogtreecommitdiff
path: root/linux/src/drivers/scsi/scsicam.c
diff options
context:
space:
mode:
Diffstat (limited to 'linux/src/drivers/scsi/scsicam.c')
-rw-r--r--linux/src/drivers/scsi/scsicam.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/linux/src/drivers/scsi/scsicam.c b/linux/src/drivers/scsi/scsicam.c
index 2c6f637..c3fb879 100644
--- a/linux/src/drivers/scsi/scsicam.c
+++ b/linux/src/drivers/scsi/scsicam.c
@@ -26,9 +26,8 @@
#include "scsi.h"
#include "hosts.h"
#include "sd.h"
+#include <scsi/scsicam.h>
-static int partsize(struct buffer_head *bh, unsigned long capacity,
- unsigned int *cyls, unsigned int *hds, unsigned int *secs);
static int setsize(unsigned long capacity,unsigned int *cyls,unsigned int *hds,
unsigned int *secs);
@@ -56,7 +55,7 @@ int scsicam_bios_param (Disk *disk, /* SCSI disk */
return -1;
/* try to infer mapping from partition table */
- ret_code = partsize (bh, (unsigned long) size, (unsigned int *) ip + 2,
+ ret_code = scsi_partsize (bh, (unsigned long) size, (unsigned int *) ip + 2,
(unsigned int *) ip + 0, (unsigned int *) ip + 1);
brelse (bh);
@@ -85,7 +84,7 @@ int scsicam_bios_param (Disk *disk, /* SCSI disk */
}
/*
* Function : static int partsize(struct buffer_head *bh, unsigned long
* capacity,unsigned int *cyls, unsigned int *hds, unsigned int *secs);
*
* Purpose : to determine the BIOS mapping used to create the partition
@@ -95,7 +94,7 @@ int scsicam_bios_param (Disk *disk, /* SCSI disk */
*
*/
-static int partsize(struct buffer_head *bh, unsigned long capacity,
+int scsi_partsize(struct buffer_head *bh, unsigned long capacity,
unsigned int *cyls, unsigned int *hds, unsigned int *secs) {
struct partition *p, *largest = NULL;
int i, largest_cyl;
@@ -85,7 +84,7 @@ int scsicam_bios_param (Disk *disk, /* SCSI disk */
}
/*
- * Function : static int partsize(struct buffer_head *bh, unsigned long
+ * Function : static int scsi_partsize(struct buffer_head *bh, unsigned long
* capacity,unsigned int *cyls, unsigned int *hds, unsigned int *secs);
*